==> 0.0.7.tar.gz: aretmis_cupps_runner/lib/screens/bp_device_screen.dart <==
import 'dart:developer';
import 'package:flutter/material.dart';
import 'package:artemis_cupps/artemis_cupps.dart';

import '../data.dart';

class BpDeviceScreen extends StatefulWidget {
  final BpDevice device;

  const BpDeviceScreen({required this.device, Key? key}) : super(key: key);

  @override
  _BpDeviceScreenState createState() => _BpDeviceScreenState();
}

class _BpDeviceScreenState extends State<BpDeviceScreen> {
  @override
  Widget build(BuildContext context) {
    double width = MediaQuery.of(context).size.width;
    BpDevice device = widget.device;
    return Scaffold(
      appBar: AppBar(
        title: Text("${device.deviceIndex} ${device.deviceName}"),
        actions: [IconButton(onPressed: (){
          device.refreshStatus();
        }, icon:const Icon(Icons.refresh))],
      ),
      body: Container(
        padding: const EdgeInsets.symmetric(horizontal: 12, vertical: 12),
        child: Column(
          children: [
            Row(
              children: [
                Expanded(flex: 1, child: Image.asset(device.deviceParameter.status.image)),
                const SizedBox(width: 12),
                Expanded(
                    flex: 2,
                    child: Column(
                      children: [
                        Row(
                          mainAxisAlignment: MainAxisAlignment.spaceBetween,
                          children: [
                            const Text("Status"),
                            Text(
                              "${device.deviceParameter.status}",
                              style: const TextStyle(fontWeight: FontWeight.bold),
                            ),
                          ],
                        ),
                        const Divider(),
                        Row(
                          mainAxisAlignment: MainAxisAlignment.spaceBetween,
                          children: [
                            const Text("Address"),
                            Text(
                              "${device.deviceParameter.ipAndPort}",
                              style: const TextStyle(fontWeight: FontWeight.bold),
                            ),
                          ],
                        ),
                        const Divider(),
                        Row(
                          mainAxisAlignment: MainAxisAlignment.spaceBetween,
                          children: [GestureDetector(
                              onTap:(){
                                // device.connect().then((value){
                                //   device.initialize();
                                // });
                              },
                              child: const Text("TCP Connection")), Icon(Icons.circle, color: device.isConnected ? Colors.green : Colors.red, size: 14)],
                        ),
                      ],
                    ))
              ],
            ),
            Row(
              children: [
                const Text("Available Modes"),
                const SizedBox(width: 12),
                Expanded(
                  child: Wrap(
                    direction: Axis.horizontal,
                    children: device.supportedInterfaceModes.map((e) => OutlinedButton(onPressed: () {}, child: Text(e.mode))).toList(),
                  ),
                ),
              ],
            ),
            const Divider(),
            Column(
              children: [
                ElevatedButton(
                  onPressed: () async {
                    final alRes  = await device.auth(airlineID: "001",font: "L");
                    log("$alRes");
                  },
                  child: const Text("Set Airline"),
                ),
                ElevatedButton(
                  onPressed: () async {
                    final logoRes  = await device.setLogo(DataExample.logoText);
                    log("$logoRes");
                  },
                  child: const Text("Set Logo"),
                ),
                ElevatedButton(
                  onPressed: () {
                    device.setPectab(DataExample.bpPetabAbomis);
                  },
                  child: const Text("Set Pectab"),
                ),
                ElevatedButton(
                  onPressed: () {
                    device.printAEA(DataExample.bpAbomis);
                  },
                  child: const Text("Print Bp Test"),
                ),
              ],
            )
          ],
        ),
      ),
    );
  }
}

==> 0.0.10.tar.gz: aretmis_cupps_runner/lib/screens/bp_device_screen.dart <==
import 'dart:developer';
import 'package:flutter/material.dart';
import 'package:artemis_cupps/artemis_cupps.dart';

import '../data.dart';

class BpDeviceScreen extends StatefulWidget {
  final BpDevice device;

  const BpDeviceScreen({required this.device, Key? key}) : super(key: key);

  @override
  _BpDeviceScreenState createState() => _BpDeviceScreenState();
}

class _BpDeviceScreenState extends State<BpDeviceScreen> {
  @override
  Widget build(BuildContext context) {
    double width = MediaQuery.of(context).size.width;
    BpDevice device = widget.device;
    return Scaffold(
      appBar: AppBar(
        title: Text("${device.deviceIndex} ${device.deviceName}"),
        actions: [IconButton(onPressed: (){
          device.refreshStatus();
        }, icon:const Icon(Icons.refresh))],
      ),
      body: Container(
        padding: const EdgeInsets.symmetric(horizontal: 12, vertical: 12),
        child: Column(
          children: [
            Row(
              children: [
                Expanded(flex: 1, child:device.isPrinting?Icon(Icons.print,size: 50): Image.asset(device.deviceParameter.status.image,package: 'artemis_cupps',)),
                const SizedBox(width: 12),
                Expanded(
                    flex: 2,
                    child: Column(
                      children: [
                        Row(
                          mainAxisAlignment: MainAxisAlignment.spaceBetween,
                          children: [
                            const Text("Status"),
                            Text(
                              "${device.deviceParameter.status}",
                              style: const TextStyle(fontWeight: FontWeight.bold),
                            ),
                          ],
                        ),
                        const Divider(),
                        Row(
                          mainAxisAlignment: MainAxisAlignment.spaceBetween,
                          children: [
                            const Text("Address"),
                            Text(
                              "${device.deviceParameter.ipAndPort}",
                              style: const TextStyle(fontWeight: FontWeight.bold),
                            ),
                          ],
                        ),
                        const Divider(),
                        Row(
                          mainAxisAlignment: MainAxisAlignment.spaceBetween,
                          children: [GestureDetector(
                              onTap:(){
                                // device.connect().then((value){
                                //   device.initialize();
                                // });
                              },
                              child: const Text("TCP Connection")), Icon(Icons.circle, color: device.isConnected ? Colors.green : Colors.red, size: 14)],
                        ),
                      ],
                    ))
              ],
            ),
            Row(
              children: [
                const Text("Available Modes"),
                const SizedBox(width: 12),
                Expanded(
                  child: Wrap(
                    direction: Axis.horizontal,
                    children: device.supportedInterfaceModes.map((e) => OutlinedButton(onPressed: () {}, child: Text(e.mode))).toList(),
                  ),
                ),
              ],
            ),
            const Divider(),
            Column(
              children: [
                ElevatedButton(
                  onPressed: () async {
                    final alRes  = await device.auth(airlineID: "001",font: "L");
                    log("$alRes");
                  },
                  child: const Text("Set Airline"),
                ),
                ElevatedButton(
                  onPressed: () async {
                    final logoRes  = await device.setLogo(DataExample.logoText);
                    log("$logoRes");
                  },
                  child: const Text("Set Logo"),
                ),
                ElevatedButton(
                  onPressed: () {
                    device.setPectab(DataExample.bpPetabAbomis);
                  },
                  child: const Text("Set Pectab"),
                ),
                ElevatedButton(
                  onPressed: ()async {
                    log("start printing");
                    CuppsCommandResponse printRes =  await device.print(DataExample.bpAbomis);
                    log("end print $printRes");
                    // device.printAEA(DataExample.bpAbomis);
                  },
                  child: Text("Print Bp Test ${device.isPrinting}"),
                ),
              ],
            )
          ],
        ),
      ),
    );
  }
}
